from typing import List, Union
from fastapi import Query
from obspy import UTCDateTime
from .DataApiQuery import (
    DEFAULT_ELEMENTS,
    FilterDataApiQuery,
    DataType,
    OutputFormat,
    SamplingPeriod,
)


def get_filter_data_query(
    id: str = Query(..., title="Observatory code"),
    starttime: UTCDateTime = Query(
        None,
        title="Start Time",
        description="Time of first requested data. Default is start of current UTC day.",
    ),
    endtime: UTCDateTime = Query(None, title="End Time"),
    elements: List[str] = Query(DEFAULT_ELEMENTS, title="Geomagnetic Elements"),
    data_type: Union[DataType, str] = Query(DataType.VARIATION, alias="type"),
    format: Union[OutputFormat, str] = Query(
        OutputFormat.IAGA2002, title="Output Format"
    ),
    input_sampling_period: Union[SamplingPeriod, float] = Query(
        SamplingPeriod.SECOND, title="Initial sampling period"
    ),
    output_sampling_period: Union[SamplingPeriod, float] = Query(
        SamplingPeriod.MINUTE, title="Output sampling period"
    ),
) -> FilterDataApiQuery:

    return FilterDataApiQuery(
        id=id,
        starttime=starttime,
        endtime=endtime,
        elements=elements,
        input_sampling_period=input_sampling_period,
        output_sampling_period=output_sampling_period,
        data_type=data_type,
        format=format,
    )
